// Thinkingdata Weex SDK v2.0.0

#import "WeexThinkingDataAnalyticsModule.h"
#import <ThinkingSDK/ThinkingAnalyticsSDK.h>

@implementation WeexThinkingDataAnalyticsModule

WX_EXPORT_METHOD(@selector(track:))
WX_EXPORT_METHOD(@selector(timeEvent:))
WX_EXPORT_METHOD(@selector(login:))
WX_EXPORT_METHOD(@selector(logout:))
WX_EXPORT_METHOD(@selector(userSet:))
WX_EXPORT_METHOD(@selector(userUnset:))
WX_EXPORT_METHOD(@selector(userSetOnce:))
WX_EXPORT_METHOD(@selector(userAdd:))
WX_EXPORT_METHOD(@selector(userDel:))
WX_EXPORT_METHOD(@selector(userAppend:))
WX_EXPORT_METHOD(@selector(setSuperProperties:))
WX_EXPORT_METHOD(@selector(unsetSuperProperty:))
WX_EXPORT_METHOD(@selector(clearSuperProperties:))
WX_EXPORT_METHOD(@selector(identify:))
WX_EXPORT_METHOD(@selector(flush:))
WX_EXPORT_METHOD(@selector(enableTracking:))
WX_EXPORT_METHOD(@selector(optInTracking:))
WX_EXPORT_METHOD(@selector(optOutTracking:))
WX_EXPORT_METHOD(@selector(optOutTrackingAndDeleteUser:))
WX_EXPORT_METHOD(@selector(enableAutoTrack:))
WX_EXPORT_METHOD(@selector(calibrateTime:))
WX_EXPORT_METHOD(@selector(calibrateTimeWithNtp:))

-(void)track:(NSDictionary *)options {
    @try {
        NSString *appId = [options objectForKey:@"appId"];
        NSString *eventName = [options objectForKey:@"eventName"];
        NSDictionary *properties = [options objectForKey:@"properties"];
        NSDate *time;
        if ([options objectForKey:@"time"]) {
         time = [NSDate dateWithTimeIntervalSince1970:[[options objectForKey:@"time"] doubleValue] / 1000.0];
        }
        NSString *timeZone = [options objectForKey:@"timeZone"];
        NSTimeZone *tz = [NSTimeZone timeZoneWithName:timeZone];

        if (appId) {
         if (tz) {
           if (time) {
             [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] track:eventName properties:properties time:time timeZone:tz];
           }
         } else if (time) {
             #pragma clang diagnostic push
             #pragma clang diagnostic ignored "-Wdeprecated-declarations"
           [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] track:eventName properties:properties time:time];
             #pragma clang diagnostic pop
         } else {
           [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] track:eventName properties:properties];
         }
        } else {
         if (tz) {
           if (time) {
             [[ThinkingAnalyticsSDK sharedInstance] track:eventName properties:properties time:time timeZone:tz];
           }
         } else if (time) {
             #pragma clang diagnostic push
             #pragma clang diagnostic ignored "-Wdeprecated-declarations"
           [[ThinkingAnalyticsSDK sharedInstance] track:eventName properties:properties time:time];
             #pragma clang diagnostic pop
         } else {
           [[ThinkingAnalyticsSDK sharedInstance] track:eventName properties:properties];
         }
        }
    } @catch (NSException *exception) {
        NSLog(@"[WeexThinkingDataAnalytics] error:%@",exception);
    }
}

-(void)timeEvent:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSString *eventName = [options objectForKey:@"eventName"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] timeEvent:eventName];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] timeEvent:eventName];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)login:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSString *loginId = [options objectForKey:@"loginId"];
    
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] login:loginId];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] login:loginId];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)logout:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] logout];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] logout];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)userSet:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSDictionary *properties = [options objectForKey:@"properties"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] user_set:properties];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] user_set:properties];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)userUnset:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSString *property = [options objectForKey:@"properties"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] user_unset:property];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] user_unset:property];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)userSetOnce:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSDictionary *properties = [options objectForKey:@"properties"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] user_setOnce:properties];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] user_setOnce:properties];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)userAdd:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSDictionary *properties = [options objectForKey:@"properties"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] user_add:properties];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] user_add:properties];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)userDel:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] user_delete];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] user_delete];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)userAppend:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSDictionary *properties = [options objectForKey:@"properties"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] user_append:properties];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] user_append:properties];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}


-(void)setSuperProperties:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSDictionary *properties = [options objectForKey:@"properties"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] setSuperProperties:properties];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] setSuperProperties:properties];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)unsetSuperProperty:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSString *property = [options objectForKey:@"properties"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] unsetSuperProperty:property];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] unsetSuperProperty:property];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)clearSuperProperties:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] clearSuperProperties];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] clearSuperProperties];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)identify:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSString *distinctId = [options objectForKey:@"distinctId"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] identify:distinctId];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] identify:distinctId];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)flush:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] flush];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] flush];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)enableTracking:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    BOOL enableTracking = [[options objectForKey:@"enableTracking"] boolValue];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] enableTracking:enableTracking];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] enableTracking:enableTracking];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)optInTracking:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] optInTracking];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] optInTracking];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)optOutTracking:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] optOutTracking];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] optOutTracking];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)optOutTrackingAndDeleteUser:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] optOutTrackingAndDeleteUser];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] optOutTrackingAndDeleteUser];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)enableAutoTrack:(NSDictionary *)options  {
  @try {
    NSString *appId = [options objectForKey:@"appId"];
    NSDictionary *autoTrackType = [options objectForKey:@"autoTrackType"];
    BOOL appStart = [[autoTrackType objectForKey:@"appStart"] boolValue];
    BOOL appEnd = [[autoTrackType objectForKey:@"appEnd"] boolValue];
    BOOL appViewCrash = [[autoTrackType objectForKey:@"appCrash"] boolValue];
    BOOL appInstall = [[autoTrackType objectForKey:@"appInstall"] boolValue];
    int autoTrackEvents = ((appStart==YES) ? 1 : 0) | ((appEnd==YES) ? 2 : 0) | ((appViewCrash==YES) ? 16 : 0) | ((appInstall==YES) ? 32 : 0);
    
    if (appId) {
      [[ThinkingAnalyticsSDK sharedInstanceWithAppid:appId] enableAutoTrack:autoTrackEvents];
    } else {
      [[ThinkingAnalyticsSDK sharedInstance] enableAutoTrack:autoTrackEvents];
    }
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)calibrateTime:(NSDictionary *)options  {
  @try {
    double timeStampMillis = [[options objectForKey:@"timeStampMillis"] doubleValue];
    [ThinkingAnalyticsSDK calibrateTime:timeStampMillis];
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

-(void)calibrateTimeWithNtp:(NSDictionary *)options  {
  @try {
    NSString *ntp_server = [options objectForKey:@"ntpServer"];
    [ThinkingAnalyticsSDK calibrateTimeWithNtp:ntp_server];
  } @catch (NSException *exception) {
    NSLog(@"[ThinkingAnalyticsSDK] error:%@",exception);
  }
}

@end
